pub struct FunctionCallOutput {
pub id: Option<String>,
pub status: Option<FunctionCallStatus>,
pub call_id: String,
pub output: String,
}Expand description
The output of a function call.
See the function calling guide for more information.
Fields
id: Option<String>The unique ID of the function tool call output. Populated when this item is returned via API.
status: Option<FunctionCallStatus>The status of the item. Populated when items are returned via API.
call_id: StringThe ID of the computer tool call that produced the output.
output: StringA JSON string of the output of the function tool call.