Event

Enum Event 

pub enum Event {
Show 23 variants ResponseCreated { response: Response, }, ResponseInProgress { response: Response, }, ResponseCompleted { response: Response, }, ResponseFailed { response: Response, }, ResponseIncomplete { response: Response, }, OutputItemAdded { item: OutputItem, output_index: u64, }, OutputItemDone { item: OutputItem, output_index: u64, }, ContentPartAdded { content_index: u64, item_id: String, output_index: u64, part: OutputContent, }, ContentPartDone { content_index: u64, item_id: String, output_index: u64, part: OutputContent, }, OutputTextDelta { content_index: u64, delta: String, item_id: String, output_index: u64, }, OutputTextAnnotationAdded { annotation: Annotation, annotation_index: u64, content_index: u64, item_id: String, output_index: u64, }, OutputTextDone { content_index: u64, item_id: String, output_index: u64, text: String, }, RefusalDelta { content_index: u64, delta: String, item_id: String, output_index: u64, }, RefusalDone { content_index: u64, item_id: String, output_index: u64, refusal: String, }, FunctionCallArgumentsDelta { delta: String, item_id: String, output_index: u64, }, FunctionCallArgumentsDone { arguments: String, item_id: String, output_index: u64, }, FileSearchCallInitiated { item_id: String, output_index: u64, }, FileSearchCallSearching { item_id: String, output_index: u64, }, FileSearchCallCompleted { item_id: String, output_index: u64, }, WebSearchCallInitiated { item_id: String, output_index: u64, }, WebSearchCallSearching { item_id: String, output_index: u64, }, WebSearchCallCompleted { item_id: String, output_index: u64, }, Error { code: Option<String>, message: String, param: Option<String>, },
}

Variants



ResponseCreated

An event that is emitted when a response is created.

Fields

response: Response

The response that was created.



ResponseInProgress

Emitted when the response is in progress.

Fields

response: Response

The response that is in progress.



ResponseCompleted

Emitted when the model response is complete.

Fields

response: Response

Properties of the completed response.



ResponseFailed

An event that is emitted when a response fails.

Fields

response: Response

The response that failed.



ResponseIncomplete

An event that is emitted when a response finishes as incomplete.

Fields

response: Response

The response that was incomplete.



OutputItemAdded

Emitted when a new output item is added.

Fields

item: OutputItem

The output item that was added.

output_index: u64

The index of the output item that was added.



OutputItemDone

Emitted when an output item is marked done.

Fields

item: OutputItem

The output item that was marked done.

output_index: u64

The index of the output item that was marked done.



ContentPartAdded

Emitted when a new content part is added.

Fields

content_index: u64

The index of the content part that was added.

item_id: String

The ID of the output item that the content part was added to.

output_index: u64

The index of the output item that the content part was added to.

part: OutputContent

The content part that was added.



ContentPartDone

Emitted when a content part is done.

Fields

content_index: u64

The index of the content part that is done.

item_id: String

The ID of the output item that the content part was added to.

output_index: u64

The index of the output item that the content part was added to.

part: OutputContent

The content part that is done.



OutputTextDelta

Emitted when there is an additional text delta.

Fields

content_index: u64

The index of the content part that the text delta was added to.

delta: String

The text delta that was added.

item_id: String

The ID of the output item that the text delta was added to.

output_index: u64

The index of the output item that the text delta was added to.



OutputTextAnnotationAdded

Emitted when a text annotation is added.

Fields

annotation: Annotation

The annotation that was added.

annotation_index: u64

The index of the annotation that was added.

content_index: u64

The index of the content part that the text annotation was added to.

item_id: String

The ID of the output item that the text annotation was added to.

output_index: u64

The index of the output item that the text annotation was added to.



OutputTextDone

Emitted when text content is finalized.

Fields

content_index: u64

The index of the content part that the text content is finalized.

item_id: String

The ID of the output item that the text content is finalized.

output_index: u64

The index of the output item that the text content is finalized.

text: String

The text content that is finalized.



RefusalDelta

Emitted when there is a partial refusal text.

Fields

content_index: u64

The index of the content part that the refusal text is added to.

delta: String

The refusal text that is added.

item_id: String

The ID of the output item that the refusal text is added to.

output_index: u64

The index of the output item that the refusal text is added to.



RefusalDone

Emitted when refusal text is finalized.

Fields

content_index: u64

The index of the content part that the refusal text is finalized.

item_id: String

The ID of the output item that the refusal text is finalized.

output_index: u64

The index of the output item that the refusal text is finalized.

refusal: String

The refusal text that is finalized.



FunctionCallArgumentsDelta

Emitted when there is a partial function-call arguments delta.

Fields

delta: String

The function-call arguments delta that is added.

item_id: String

The ID of the output item that the function-call arguments delta is added to.

output_index: u64

The index of the output item that the function-call arguments delta is added to.



FunctionCallArgumentsDone

Emitted when function-call arguments are finalized.

Fields

arguments: String

The function-call arguments.

item_id: String

The ID of the item.

output_index: u64

The index of the output item.



FileSearchCallInitiated

Emitted when a file search call is initiated.

Fields

item_id: String

The ID of the output item that the file search call is initiated.

output_index: u64

The index of the output item that the file search call is initiated.



FileSearchCallSearching

Emitted when a file search is currently searching.

Fields

item_id: String

The ID of the output item that the file search call is searching.

output_index: u64

The index of the output item that the file search call is searching.



FileSearchCallCompleted

Emitted when a file search call is completed (results found).

Fields

item_id: String

The ID of the output item that the file search call completed at.

output_index: u64

The index of the output item that the file search call completed at.



WebSearchCallInitiated

Emitted when a web search call is initiated.

Fields

item_id: String

Unique ID for the output item associated with the web search call.

output_index: u64

The index of the output item that the web search call is associated with.



WebSearchCallSearching

Emitted when a web search call is executing.

Fields

item_id: String

Unique ID for the output item associated with the web search call.

output_index: u64

The index of the output item that the web search call is associated with.



WebSearchCallCompleted

Emitted when a web search call is completed.

Fields

item_id: String

Unique ID for the output item associated with the web search call.

output_index: u64

The index of the output item that the web search call is associated with.



Error

Emitted when an error occurs.

Fields

code: Option<String>

The error code.

message: String

The error message.

param: Option<String>

The error parameter.